.. -*- mode: rst -*-

Team
----

This work is made available by a community of people, amoung which the CEA Neurospin BAOBAB laboratory.

.. _core_devs:

Core developers
...............

The core developers are:

* Antoine Grigis
* Benoit Dufumier
* Joel Chavas

Other contributors
..................

Some other past or present contributors are:

* Vincent Frouin
* Edouard Duchesnay
* Jean-François Mangin
